@@ -16,11 +16,7 @@ async def get_us_proxies(ptype: str):
             data = list(map(lambda x: x.text, row.find_all("td")))
             host = data[0]
             port = data[1]
-            if data[6].lower() == "yes":
-                version = "https"
-            else:
-                version = "http"
-
+            version = "https" if data[6].lower() == "yes" else "http"
             if version == ptype:
                 proxies.append(f"{host}:{port}")
 
